==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterManagerStatusBuilder extends ClusterManagerStatusFluentImpl<ClusterManagerStatusBuilder> implements VisitableBuilder<ClusterManagerStatus,ClusterManagerStatusBuilder>{
  public ClusterManagerStatusBuilder() {
    this(false);
  }
  public ClusterManagerStatusBuilder(Boolean validationEnabled) {
    this(new ClusterManagerStatus(), validationEnabled);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterManagerStatus(), validationEnabled);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,ClusterManagerStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,ClusterManagerStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withGenerations(instance.getGenerations());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withRelatedResources(instance.getRelatedResources());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatus instance) {
    this(instance,false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withGenerations(instance.getGenerations());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withRelatedResources(instance.getRelatedResources());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterManagerStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterManagerStatus build() {
    ClusterManagerStatus buildable = new ClusterManagerStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getRelatedResources());
    return buildable;
  }
  
}

==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterManagerStatusBuilder extends ClusterManagerStatusFluent<ClusterManagerStatusBuilder> implements VisitableBuilder<ClusterManagerStatus,ClusterManagerStatusBuilder>{
  public ClusterManagerStatusBuilder() {
    this(false);
  }
  public ClusterManagerStatusBuilder(Boolean validationEnabled) {
    this(new ClusterManagerStatus(), validationEnabled);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterManagerStatus(), validationEnabled);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,ClusterManagerStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatusFluent<?> fluent,ClusterManagerStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterManagerStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withGenerations(instance.getGenerations());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withRelatedResources(instance.getRelatedResources());
      fluent.withConditions(instance.getConditions());
      fluent.withGenerations(instance.getGenerations());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withRelatedResources(instance.getRelatedResources());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatus instance) {
    this(instance,false);
  }
  public ClusterManagerStatusBuilder(ClusterManagerStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterManagerStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withGenerations(instance.getGenerations());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withRelatedResources(instance.getRelatedResources());
      this.withConditions(instance.getConditions());
      this.withGenerations(instance.getGenerations());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withRelatedResources(instance.getRelatedResources());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterManagerStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterManagerStatus build() {
    ClusterManagerStatus buildable = new ClusterManagerStatus(fluent.getConditions(),fluent.buildGenerations(),fluent.getObservedGeneration(),fluent.buildRelatedResources());
    return buildable;
  }
  
}
